#!/opt/concourse/worker/volumes/live/7a2bf533-8e77-4a4b-7e5f-264640c13447/volume/anaconda-navigator_1645725746654/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/opt/concourse/worker/volumes/live/7a2bf533-8e77-4a4b-7e5f-264640c13447/volume/anaconda-navigator_1645725746654/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin/anaconda-navigator"])
